import argparse

import yaml

from metadata_client.metadata_client import MetadataClient


parser = argparse.ArgumentParser(
    description='Update run status at MDC for a given run id.')
parser.add_argument('--conf-file', type=str, help='Path to webservice config',
                    default='/home/xcal/calibration_webservice_deployed/webservice/webservice.yaml')  # noqa
parser.add_argument('--flg', type=str, choices=["NA", "R", "A"],
                    help='Status flag for MDC request: NA - not available, R - running, A - available.')  # noqa
parser.add_argument('--rid', type=int, help='Run id from MDC')
parser.add_argument('--msg', type=str, help='Message string to MDC',
                    default='Error while job submission')
args = vars(parser.parse_args())

conf_file = args['conf_file']
rid = args['rid']
flg = args['flg']
msg = args['msg']

with open(conf_file, "r") as f:
    config = yaml.load(f.read(), Loader=yaml.FullLoader)

mdconf = config['metadata-client']
client_conn = MetadataClient(client_id=mdconf['user-id'],
                             client_secret=mdconf['user-secret'],
                             user_email=mdconf['user-email'],
                             token_url=mdconf['token-url'],
                             refresh_url=mdconf['refresh-url'],
                             auth_url=mdconf['auth-url'],
                             scope=mdconf['scope'],
                             base_api_url=mdconf['base-api-url'])

response = client_conn.update_run_api(rid, {'flg_cal_data_status': flg,
                                            'cal_pipeline_reply': msg})

if response.status_code == 200:
    print('Run is updated')
else:
    print(f'Update failed {response}')

